# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eibc/core/client/v1/query.proto\x12\x12ibc.core.client.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/commitment/v1/commitment.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\"6\n\x17QueryClientStateRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"\xae\x01\n\x18QueryClientStateResponse\x12\x37\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x63lientState\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"b\n\x18QueryClientStatesRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xd4\x01\n\x19QueryClientStatesResponse\x12n\n\rclient_states\x18\x01 \x03(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStatesR\x0c\x63lientStates\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xb0\x01\n\x1aQueryConsensusStateRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\'\n\x0frevision_number\x18\x02 \x01(\x04R\x0erevisionNumber\x12\'\n\x0frevision_height\x18\x03 \x01(\x04R\x0erevisionHeight\x12#\n\rlatest_height\x18\x04 \x01(\x08R\x0clatestHeight\"\xb7\x01\n\x1bQueryConsensusStateResponse\x12=\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\x82\x01\n\x1bQueryConsensusStatesRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xc6\x01\n\x1cQueryConsensusStatesResponse\x12]\n\x10\x63onsensus_states\x18\x01 \x03(\x0b\x32,.ibc.core.client.v1.ConsensusStateWithHeightB\x04\xc8\xde\x1f\x00R\x0f\x63onsensusStates\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x88\x01\n!QueryConsensusStateHeightsRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xc7\x01\n\"QueryConsensusStateHeightsResponse\x12X\n\x17\x63onsensus_state_heights\x18\x01 \x03(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x15\x63onsensusStateHeights\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"7\n\x18QueryClientStatusRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"3\n\x19QueryClientStatusResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"\x1a\n\x18QueryClientParamsRequest\"O\n\x19QueryClientParamsResponse\x12\x32\n\x06params\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.ParamsR\x06params\"!\n\x1fQueryUpgradedClientStateRequest\"l\n QueryUpgradedClientStateResponse\x12H\n\x15upgraded_client_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x13upgradedClientState\"$\n\"QueryUpgradedConsensusStateRequest\"u\n#QueryUpgradedConsensusStateResponse\x12N\n\x18upgraded_consensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x16upgradedConsensusState\"\xb7\x02\n\x1cQueryVerifyMembershipRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\x12I\n\x0bmerkle_path\x18\x04 \x01(\x0b\x32\".ibc.core.commitment.v1.MerklePathB\x04\xc8\xde\x1f\x00R\nmerklePath\x12\x14\n\x05value\x18\x05 \x01(\x0cR\x05value\x12\x1d\n\ntime_delay\x18\x06 \x01(\x04R\ttimeDelay\x12\x1f\n\x0b\x62lock_delay\x18\x07 \x01(\x04R\nblockDelay\"9\n\x1dQueryVerifyMembershipResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success2\x82\x0e\n\x05Query\x12\x9f\x01\n\x0b\x43lientState\x12+.ibc.core.client.v1.QueryClientStateRequest\x1a,.ibc.core.client.v1.QueryClientStateResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_states/{client_id}\x12\x96\x01\n\x0c\x43lientStates\x12,.ibc.core.client.v1.QueryClientStatesRequest\x1a-.ibc.core.client.v1.QueryClientStatesResponse\")\x82\xd3\xe4\x93\x02#\x12!/ibc/core/client/v1/client_states\x12\xdf\x01\n\x0e\x43onsensusState\x12..ibc.core.client.v1.QueryConsensusStateRequest\x1a/.ibc.core.client.v1.QueryConsensusStateResponse\"l\x82\xd3\xe4\x93\x02\x66\x12\x64/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}\x12\xae\x01\n\x0f\x43onsensusStates\x12/.ibc.core.client.v1.QueryConsensusStatesRequest\x1a\x30.ibc.core.client.v1.QueryConsensusStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/ibc/core/client/v1/consensus_states/{client_id}\x12\xc8\x01\n\x15\x43onsensusStateHeights\x12\x35.ibc.core.client.v1.QueryConsensusStateHeightsRequest\x1a\x36.ibc.core.client.v1.QueryConsensusStateHeightsResponse\"@\x82\xd3\xe4\x93\x02:\x12\x38/ibc/core/client/v1/consensus_states/{client_id}/heights\x12\xa2\x01\n\x0c\x43lientStatus\x12,.ibc.core.client.v1.QueryClientStatusRequest\x1a-.ibc.core.client.v1.QueryClientStatusResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_status/{client_id}\x12\x8f\x01\n\x0c\x43lientParams\x12,.ibc.core.client.v1.QueryClientParamsRequest\x1a-.ibc.core.client.v1.QueryClientParamsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/ibc/core/client/v1/params\x12\xb4\x01\n\x13UpgradedClientState\x12\x33.ibc.core.client.v1.QueryUpgradedClientStateRequest\x1a\x34.ibc.core.client.v1.QueryUpgradedClientStateResponse\"2\x82\xd3\xe4\x93\x02,\x12*/ibc/core/client/v1/upgraded_client_states\x12\xc0\x01\n\x16UpgradedConsensusState\x12\x36.ibc.core.client.v1.QueryUpgradedConsensusStateRequest\x1a\x37.ibc.core.client.v1.QueryUpgradedConsensusStateResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/upgraded_consensus_states\x12\xae\x01\n\x10VerifyMembership\x12\x30.ibc.core.client.v1.QueryVerifyMembershipRequest\x1a\x31.ibc.core.client.v1.QueryVerifyMembershipResponse\"5\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02*\"%/ibc/core/client/v1/verify_membership:\x01*B\xc9\x01\n\x16\x63om.ibc.core.client.v1B\nQueryProtoP\x01Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\xa2\x02\x03ICC\xaa\x02\x12Ibc.Core.Client.V1\xca\x02\x12Ibc\\Core\\Client\\V1\xe2\x02\x1eIbc\\Core\\Client\\V1\\GPBMetadata\xea\x02\x15Ibc::Core::Client::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.ibc.core.client.v1B\nQueryProtoP\001Z8github.com/cosmos/ibc-go/v8/modules/core/02-client/types\242\002\003ICC\252\002\022Ibc.Core.Client.V1\312\002\022Ibc\\Core\\Client\\V1\342\002\036Ibc\\Core\\Client\\V1\\GPBMetadata\352\002\025Ibc::Core::Client::V1'
  _globals['_QUERYCLIENTSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCLIENTSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCLIENTSTATESRESPONSE'].fields_by_name['client_states']._loaded_options = None
  _globals['_QUERYCLIENTSTATESRESPONSE'].fields_by_name['client_states']._serialized_options = b'\310\336\037\000\252\337\037\026IdentifiedClientStates'
  _globals['_QUERYCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONSENSUSSTATESRESPONSE'].fields_by_name['consensus_states']._loaded_options = None
  _globals['_QUERYCONSENSUSSTATESRESPONSE'].fields_by_name['consensus_states']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONSENSUSSTATEHEIGHTSRESPONSE'].fields_by_name['consensus_state_heights']._loaded_options = None
  _globals['_QUERYCONSENSUSSTATEHEIGHTSRESPONSE'].fields_by_name['consensus_state_heights']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST'].fields_by_name['merkle_path']._loaded_options = None
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST'].fields_by_name['merkle_path']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['ClientState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientState']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/client_states/{client_id}'
  _globals['_QUERY'].methods_by_name['ClientStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientStates']._serialized_options = b'\202\323\344\223\002#\022!/ibc/core/client/v1/client_states'
  _globals['_QUERY'].methods_by_name['ConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConsensusState']._serialized_options = b'\202\323\344\223\002f\022d/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}'
  _globals['_QUERY'].methods_by_name['ConsensusStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConsensusStates']._serialized_options = b'\202\323\344\223\0022\0220/ibc/core/client/v1/consensus_states/{client_id}'
  _globals['_QUERY'].methods_by_name['ConsensusStateHeights']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConsensusStateHeights']._serialized_options = b'\202\323\344\223\002:\0228/ibc/core/client/v1/consensus_states/{client_id}/heights'
  _globals['_QUERY'].methods_by_name['ClientStatus']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientStatus']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/client_status/{client_id}'
  _globals['_QUERY'].methods_by_name['ClientParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientParams']._serialized_options = b'\202\323\344\223\002\034\022\032/ibc/core/client/v1/params'
  _globals['_QUERY'].methods_by_name['UpgradedClientState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UpgradedClientState']._serialized_options = b'\202\323\344\223\002,\022*/ibc/core/client/v1/upgraded_client_states'
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/upgraded_consensus_states'
  _globals['_QUERY'].methods_by_name['VerifyMembership']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VerifyMembership']._serialized_options = b'\210\347\260*\001\202\323\344\223\002*\"%/ibc/core/client/v1/verify_membership:\001*'
  _globals['_QUERYCLIENTSTATEREQUEST']._serialized_start=280
  _globals['_QUERYCLIENTSTATEREQUEST']._serialized_end=334
  _globals['_QUERYCLIENTSTATERESPONSE']._serialized_start=337
  _globals['_QUERYCLIENTSTATERESPONSE']._serialized_end=511
  _globals['_QUERYCLIENTSTATESREQUEST']._serialized_start=513
  _globals['_QUERYCLIENTSTATESREQUEST']._serialized_end=611
  _globals['_QUERYCLIENTSTATESRESPONSE']._serialized_start=614
  _globals['_QUERYCLIENTSTATESRESPONSE']._serialized_end=826
  _globals['_QUERYCONSENSUSSTATEREQUEST']._serialized_start=829
  _globals['_QUERYCONSENSUSSTATEREQUEST']._serialized_end=1005
  _globals['_QUERYCONSENSUSSTATERESPONSE']._serialized_start=1008
  _globals['_QUERYCONSENSUSSTATERESPONSE']._serialized_end=1191
  _globals['_QUERYCONSENSUSSTATESREQUEST']._serialized_start=1194
  _globals['_QUERYCONSENSUSSTATESREQUEST']._serialized_end=1324
  _globals['_QUERYCONSENSUSSTATESRESPONSE']._serialized_start=1327
  _globals['_QUERYCONSENSUSSTATESRESPONSE']._serialized_end=1525
  _globals['_QUERYCONSENSUSSTATEHEIGHTSREQUEST']._serialized_start=1528
  _globals['_QUERYCONSENSUSSTATEHEIGHTSREQUEST']._serialized_end=1664
  _globals['_QUERYCONSENSUSSTATEHEIGHTSRESPONSE']._serialized_start=1667
  _globals['_QUERYCONSENSUSSTATEHEIGHTSRESPONSE']._serialized_end=1866
  _globals['_QUERYCLIENTSTATUSREQUEST']._serialized_start=1868
  _globals['_QUERYCLIENTSTATUSREQUEST']._serialized_end=1923
  _globals['_QUERYCLIENTSTATUSRESPONSE']._serialized_start=1925
  _globals['_QUERYCLIENTSTATUSRESPONSE']._serialized_end=1976
  _globals['_QUERYCLIENTPARAMSREQUEST']._serialized_start=1978
  _globals['_QUERYCLIENTPARAMSREQUEST']._serialized_end=2004
  _globals['_QUERYCLIENTPARAMSRESPONSE']._serialized_start=2006
  _globals['_QUERYCLIENTPARAMSRESPONSE']._serialized_end=2085
  _globals['_QUERYUPGRADEDCLIENTSTATEREQUEST']._serialized_start=2087
  _globals['_QUERYUPGRADEDCLIENTSTATEREQUEST']._serialized_end=2120
  _globals['_QUERYUPGRADEDCLIENTSTATERESPONSE']._serialized_start=2122
  _globals['_QUERYUPGRADEDCLIENTSTATERESPONSE']._serialized_end=2230
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_start=2232
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_end=2268
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_start=2270
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_end=2387
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST']._serialized_start=2390
  _globals['_QUERYVERIFYMEMBERSHIPREQUEST']._serialized_end=2701
  _globals['_QUERYVERIFYMEMBERSHIPRESPONSE']._serialized_start=2703
  _globals['_QUERYVERIFYMEMBERSHIPRESPONSE']._serialized_end=2760
  _globals['_QUERY']._serialized_start=2763
  _globals['_QUERY']._serialized_end=4557
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.auction.v1beta1 import (
    query_pb2 as auction_query_pb,
    query_pb2_grpc as auction_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcAuctionApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = auction_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = auction_query_pb.QueryAuctionParamsRequest()
        response = await self._execute_call(call=self._stub.AuctionParams, request=request)

        return response

    async def fetch_module_state(self) -> Dict[str, Any]:
        request = auction_query_pb.QueryModuleStateRequest()
        response = await self._execute_call(call=self._stub.AuctionModuleState, request=request)

        return response

    async def fetch_current_basket(self) -> Dict[str, Any]:
        request = auction_query_pb.QueryCurrentAuctionBasketRequest()
        response = await self._execute_call(call=self._stub.CurrentAuctionBasket, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_campaign_rpc_pb2 as exchange_dot_injective__campaign__rpc__pb2


class InjectiveCampaignRPCStub(object):
    """InjectiveCampaignRPC defined a gRPC service for Injective Campaigns.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ranking = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/Ranking',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.RankingRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.RankingResponse.FromString,
                _registered_method=True)
        self.Campaigns = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/Campaigns',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsResponse.FromString,
                _registered_method=True)
        self.CampaignsV2 = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/CampaignsV2',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Response.FromString,
                _registered_method=True)
        self.ListGuilds = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/ListGuilds',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildsResponse.FromString,
                _registered_method=True)
        self.ListGuildMembers = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/ListGuildMembers',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersResponse.FromString,
                _registered_method=True)
        self.GetGuildMember = channel.unary_unary(
                '/injective_campaign_rpc.InjectiveCampaignRPC/GetGuildMember',
                request_serializer=exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberResponse.FromString,
                _registered_method=True)


class InjectiveCampaignRPCServicer(object):
    """InjectiveCampaignRPC defined a gRPC service for Injective Campaigns.
    """

    def Ranking(self, request, context):
        """Lists all participants in campaign
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Campaigns(self, request, context):
        """List current round active campaigns
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CampaignsV2(self, request, context):
        """List campaigns v2
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGuilds(self, request, context):
        """List guilds by campaign
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListGuildMembers(self, request, context):
        """List guild members of given campaign and guildId
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGuildMember(self, request, context):
        """Get single member guild info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveCampaignRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ranking': grpc.unary_unary_rpc_method_handler(
                    servicer.Ranking,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.RankingRequest.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.RankingResponse.SerializeToString,
            ),
            'Campaigns': grpc.unary_unary_rpc_method_handler(
                    servicer.Campaigns,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsRequest.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsResponse.SerializeToString,
            ),
            'CampaignsV2': grpc.unary_unary_rpc_method_handler(
                    servicer.CampaignsV2,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Request.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Response.SerializeToString,
            ),
            'ListGuilds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGuilds,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildsRequest.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildsResponse.SerializeToString,
            ),
            'ListGuildMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListGuildMembers,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersRequest.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersResponse.SerializeToString,
            ),
            'GetGuildMember': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGuildMember,
                    request_deserializer=exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberRequest.FromString,
                    response_serializer=exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_campaign_rpc.InjectiveCampaignRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_campaign_rpc.InjectiveCampaignRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveCampaignRPC(object):
    """InjectiveCampaignRPC defined a gRPC service for Injective Campaigns.
    """

    @staticmethod
    def Ranking(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/Ranking',
            exchange_dot_injective__campaign__rpc__pb2.RankingRequest.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.RankingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Campaigns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/Campaigns',
            exchange_dot_injective__campaign__rpc__pb2.CampaignsRequest.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.CampaignsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CampaignsV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/CampaignsV2',
            exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Request.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.CampaignsV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListGuilds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/ListGuilds',
            exchange_dot_injective__campaign__rpc__pb2.ListGuildsRequest.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.ListGuildsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListGuildMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/ListGuildMembers',
            exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersRequest.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.ListGuildMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetGuildMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_campaign_rpc.InjectiveCampaignRPC/GetGuildMember',
            exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberRequest.SerializeToString,
            exchange_dot_injective__campaign__rpc__pb2.GetGuildMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/version/v1/version.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/version/v1/version.proto\x12\x1c\x63ometbft.services.version.v1\"\x13\n\x11GetVersionRequest\"d\n\x12GetVersionResponse\x12\x12\n\x04node\x18\x01 \x01(\tR\x04node\x12\x12\n\x04\x61\x62\x63i\x18\x02 \x01(\tR\x04\x61\x62\x63i\x12\x10\n\x03p2p\x18\x03 \x01(\x04R\x03p2p\x12\x14\n\x05\x62lock\x18\x04 \x01(\x04R\x05\x62lockB\x82\x02\n com.cometbft.services.version.v1B\x0cVersionProtoP\x01Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\xa2\x02\x03\x43SV\xaa\x02\x1c\x43ometbft.Services.Version.V1\xca\x02\x1c\x43ometbft\\Services\\Version\\V1\xe2\x02(Cometbft\\Services\\Version\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Version::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.version.v1.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.version.v1B\014VersionProtoP\001Z=github.com/cometbft/cometbft/api/cometbft/services/version/v1\242\002\003CSV\252\002\034Cometbft.Services.Version.V1\312\002\034Cometbft\\Services\\Version\\V1\342\002(Cometbft\\Services\\Version\\V1\\GPBMetadata\352\002\037Cometbft::Services::Version::V1'
  _globals['_GETVERSIONREQUEST']._serialized_start=76
  _globals['_GETVERSIONREQUEST']._serialized_end=95
  _globals['_GETVERSIONRESPONSE']._serialized_start=97
  _globals['_GETVERSIONRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/event.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/event.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\"\x96\x01\n\nEventGrant\x12 \n\x0cmsg_type_url\x18\x02 \x01(\tR\nmsgTypeUrl\x12\x32\n\x07granter\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granter\x12\x32\n\x07grantee\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07grantee\"\x97\x01\n\x0b\x45ventRevoke\x12 \n\x0cmsg_type_url\x18\x02 \x01(\tR\nmsgTypeUrl\x12\x32\n\x07granter\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granter\x12\x32\n\x07grantee\x18\x04 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x07granteeB\xbe\x01\n\x18\x63om.cosmos.authz.v1beta1B\nEventProtoP\x01Z$github.com/cosmos/cosmos-sdk/x/authz\xa2\x02\x03\x43\x41X\xaa\x02\x14\x43osmos.Authz.V1beta1\xca\x02\x14\x43osmos\\Authz\\V1beta1\xe2\x02 Cosmos\\Authz\\V1beta1\\GPBMetadata\xea\x02\x16\x43osmos::Authz::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.cosmos.authz.v1beta1B\nEventProtoP\001Z$github.com/cosmos/cosmos-sdk/x/authz\242\002\003CAX\252\002\024Cosmos.Authz.V1beta1\312\002\024Cosmos\\Authz\\V1beta1\342\002 Cosmos\\Authz\\V1beta1\\GPBMetadata\352\002\026Cosmos::Authz::V1beta1'
  _globals['_EVENTGRANT'].fields_by_name['granter']._loaded_options = None
  _globals['_EVENTGRANT'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTGRANT'].fields_by_name['grantee']._loaded_options = None
  _globals['_EVENTGRANT'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTREVOKE'].fields_by_name['granter']._loaded_options = None
  _globals['_EVENTREVOKE'].fields_by_name['granter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTREVOKE'].fields_by_name['grantee']._loaded_options = None
  _globals['_EVENTREVOKE'].fields_by_name['grantee']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTGRANT']._serialized_start=86
  _globals['_EVENTGRANT']._serialized_end=236
  _globals['_EVENTREVOKE']._serialized_start=239
  _globals['_EVENTREVOKE']._serialized_end=390
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crisis/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/crisis/v1beta1/genesis.proto\x12\x15\x63osmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"W\n\x0cGenesisState\x12G\n\x0c\x63onstant_fee\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0b\x63onstantFeeB\xcc\x01\n\x19\x63om.cosmos.crisis.v1beta1B\x0cGenesisProtoP\x01Z+github.com/cosmos/cosmos-sdk/x/crisis/types\xa2\x02\x03\x43\x43X\xaa\x02\x15\x43osmos.Crisis.V1beta1\xca\x02\x15\x43osmos\\Crisis\\V1beta1\xe2\x02!Cosmos\\Crisis\\V1beta1\\GPBMetadata\xea\x02\x17\x43osmos::Crisis::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cosmos.crisis.v1beta1B\014GenesisProtoP\001Z+github.com/cosmos/cosmos-sdk/x/crisis/types\242\002\003CCX\252\002\025Cosmos.Crisis.V1beta1\312\002\025Cosmos\\Crisis\\V1beta1\342\002!Cosmos\\Crisis\\V1beta1\\GPBMetadata\352\002\027Cosmos::Crisis::V1beta1'
  _globals['_GENESISSTATE'].fields_by_name['constant_fee']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['constant_fee']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=135
  _globals['_GENESISSTATE']._serialized_end=222
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.permissions.v1beta1 import query_pb2 as injective_dot_permissions_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Params',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.NamespaceDenoms = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/NamespaceDenoms',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsResponse.FromString,
                _registered_method=True)
        self.Namespaces = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Namespaces',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesResponse.FromString,
                _registered_method=True)
        self.Namespace = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Namespace',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceResponse.FromString,
                _registered_method=True)
        self.RolesByActor = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/RolesByActor',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorResponse.FromString,
                _registered_method=True)
        self.ActorsByRole = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/ActorsByRole',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleResponse.FromString,
                _registered_method=True)
        self.RoleManagers = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/RoleManagers',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersResponse.FromString,
                _registered_method=True)
        self.RoleManager = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/RoleManager',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerResponse.FromString,
                _registered_method=True)
        self.PolicyStatuses = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/PolicyStatuses',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesResponse.FromString,
                _registered_method=True)
        self.PolicyManagerCapabilities = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/PolicyManagerCapabilities',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesResponse.FromString,
                _registered_method=True)
        self.Vouchers = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Vouchers',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersResponse.FromString,
                _registered_method=True)
        self.Voucher = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Voucher',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherResponse.FromString,
                _registered_method=True)
        self.PermissionsModuleState = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/PermissionsModuleState',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Params defines a gRPC query method that returns the permissions module's
        parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NamespaceDenoms(self, request, context):
        """NamespaceDenoms defines a gRPC query method that returns the denoms for
        which a namespace exists
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Namespaces(self, request, context):
        """Namespaces defines a gRPC query method that returns the permissions
        module's created namespaces.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Namespace(self, request, context):
        """Namespace defines a gRPC query method that returns the permissions
        module's namespace associated with the provided denom.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RolesByActor(self, request, context):
        """RolesByActor defines a gRPC query method that returns roles for the actor
        in the namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ActorsByRole(self, request, context):
        """ActorsByRole defines a gRPC query method that returns a namespace's roles
        associated with the provided actor.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RoleManagers(self, request, context):
        """RoleManagers defines a gRPC query method that returns a namespace's role
        managers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RoleManager(self, request, context):
        """RoleManager defines a gRPC query method that returns the roles a given role
        manager manages for a given namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PolicyStatuses(self, request, context):
        """PolicyStatuses defines a gRPC query method that returns a namespace's
        policy statuses
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PolicyManagerCapabilities(self, request, context):
        """PolicyManagerCapabilities defines a gRPC query method that returns a
        namespace's policy manager capabilities
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vouchers(self, request, context):
        """Vouchers defines a gRPC query method for the vouchers for a given denom
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Voucher(self, request, context):
        """Voucher defines a gRPC query method for the vouchers for a given denom and
        address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PermissionsModuleState(self, request, context):
        """Retrieves the entire permissions module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'NamespaceDenoms': grpc.unary_unary_rpc_method_handler(
                    servicer.NamespaceDenoms,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsResponse.SerializeToString,
            ),
            'Namespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.Namespaces,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesResponse.SerializeToString,
            ),
            'Namespace': grpc.unary_unary_rpc_method_handler(
                    servicer.Namespace,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceResponse.SerializeToString,
            ),
            'RolesByActor': grpc.unary_unary_rpc_method_handler(
                    servicer.RolesByActor,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorResponse.SerializeToString,
            ),
            'ActorsByRole': grpc.unary_unary_rpc_method_handler(
                    servicer.ActorsByRole,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleResponse.SerializeToString,
            ),
            'RoleManagers': grpc.unary_unary_rpc_method_handler(
                    servicer.RoleManagers,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersResponse.SerializeToString,
            ),
            'RoleManager': grpc.unary_unary_rpc_method_handler(
                    servicer.RoleManager,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerResponse.SerializeToString,
            ),
            'PolicyStatuses': grpc.unary_unary_rpc_method_handler(
                    servicer.PolicyStatuses,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesResponse.SerializeToString,
            ),
            'PolicyManagerCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.PolicyManagerCapabilities,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesResponse.SerializeToString,
            ),
            'Vouchers': grpc.unary_unary_rpc_method_handler(
                    servicer.Vouchers,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersResponse.SerializeToString,
            ),
            'Voucher': grpc.unary_unary_rpc_method_handler(
                    servicer.Voucher,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherResponse.SerializeToString,
            ),
            'PermissionsModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.PermissionsModuleState,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.permissions.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.permissions.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Params',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NamespaceDenoms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/NamespaceDenoms',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceDenomsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Namespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Namespaces',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespacesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Namespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Namespace',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RolesByActor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/RolesByActor',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRolesByActorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ActorsByRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/ActorsByRole',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryActorsByRoleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RoleManagers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/RoleManagers',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RoleManager(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/RoleManager',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryRoleManagerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PolicyStatuses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/PolicyStatuses',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyStatusesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PolicyManagerCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/PolicyManagerCapabilities',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryPolicyManagerCapabilitiesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Vouchers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Vouchers',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Voucher(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Voucher',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVoucherResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PermissionsModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/PermissionsModuleState',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/crypto/v1beta1/ethsecp256k1/keys.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0injective/crypto/v1beta1/ethsecp256k1/keys.proto\x12%injective.crypto.v1beta1.ethsecp256k1\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"O\n\x06PubKey\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key:3\x98\xa0\x1f\x00\x8a\xe7\xb0*\x1cinjective/PubKeyEthSecp256k1\x92\xe7\xb0*\tkey_field\"M\n\x07PrivKey\x12\x10\n\x03key\x18\x01 \x01(\x0cR\x03key:0\x8a\xe7\xb0*\x1dinjective/PrivKeyEthSecp256k1\x92\xe7\xb0*\tkey_fieldB\xbb\x02\n)com.injective.crypto.v1beta1.ethsecp256k1B\tKeysProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1\xa2\x02\x04ICVE\xaa\x02%Injective.Crypto.V1beta1.Ethsecp256k1\xca\x02%Injective\\Crypto\\V1beta1\\Ethsecp256k1\xe2\x02\x31Injective\\Crypto\\V1beta1\\Ethsecp256k1\\GPBMetadata\xea\x02(Injective::Crypto::V1beta1::Ethsecp256k1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.crypto.v1beta1.ethsecp256k1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.injective.crypto.v1beta1.ethsecp256k1B\tKeysProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1\242\002\004ICVE\252\002%Injective.Crypto.V1beta1.Ethsecp256k1\312\002%Injective\\Crypto\\V1beta1\\Ethsecp256k1\342\0021Injective\\Crypto\\V1beta1\\Ethsecp256k1\\GPBMetadata\352\002(Injective::Crypto::V1beta1::Ethsecp256k1'
  _globals['_PUBKEY']._loaded_options = None
  _globals['_PUBKEY']._serialized_options = b'\230\240\037\000\212\347\260*\034injective/PubKeyEthSecp256k1\222\347\260*\tkey_field'
  _globals['_PRIVKEY']._loaded_options = None
  _globals['_PRIVKEY']._serialized_options = b'\212\347\260*\035injective/PrivKeyEthSecp256k1\222\347\260*\tkey_field'
  _globals['_PUBKEY']._serialized_start=132
  _globals['_PUBKEY']._serialized_end=211
  _globals['_PRIVKEY']._serialized_start=213
  _globals['_PRIVKEY']._serialized_end=290
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/blocksync/v1beta1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.types.v1beta1 import block_pb2 as cometbft_dot_types_dot_v1beta1_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cometbft/blocksync/v1beta1/types.proto\x12\x1a\x63ometbft.blocksync.v1beta1\x1a\"cometbft/types/v1beta1/block.proto\"&\n\x0c\x42lockRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\")\n\x0fNoBlockResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"D\n\rBlockResponse\x12\x33\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1d.cometbft.types.v1beta1.BlockR\x05\x62lock\"\x0f\n\rStatusRequest\"<\n\x0eStatusResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\x03R\x04\x62\x61se\"\xbb\x03\n\x07Message\x12O\n\rblock_request\x18\x01 \x01(\x0b\x32(.cometbft.blocksync.v1beta1.BlockRequestH\x00R\x0c\x62lockRequest\x12Y\n\x11no_block_response\x18\x02 \x01(\x0b\x32+.cometbft.blocksync.v1beta1.NoBlockResponseH\x00R\x0fnoBlockResponse\x12R\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32).cometbft.blocksync.v1beta1.BlockResponseH\x00R\rblockResponse\x12R\n\x0estatus_request\x18\x04 \x01(\x0b\x32).cometbft.blocksync.v1beta1.StatusRequestH\x00R\rstatusRequest\x12U\n\x0fstatus_response\x18\x05 \x01(\x0b\x32*.cometbft.blocksync.v1beta1.StatusResponseH\x00R\x0estatusResponseB\x05\n\x03sumB\xf3\x01\n\x1e\x63om.cometbft.blocksync.v1beta1B\nTypesProtoP\x01Z;github.com/cometbft/cometbft/api/cometbft/blocksync/v1beta1\xa2\x02\x03\x43\x42X\xaa\x02\x1a\x43ometbft.Blocksync.V1beta1\xca\x02\x1a\x43ometbft\\Blocksync\\V1beta1\xe2\x02&Cometbft\\Blocksync\\V1beta1\\GPBMetadata\xea\x02\x1c\x43ometbft::Blocksync::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.blocksync.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cometbft.blocksync.v1beta1B\nTypesProtoP\001Z;github.com/cometbft/cometbft/api/cometbft/blocksync/v1beta1\242\002\003CBX\252\002\032Cometbft.Blocksync.V1beta1\312\002\032Cometbft\\Blocksync\\V1beta1\342\002&Cometbft\\Blocksync\\V1beta1\\GPBMetadata\352\002\034Cometbft::Blocksync::V1beta1'
  _globals['_BLOCKREQUEST']._serialized_start=106
  _globals['_BLOCKREQUEST']._serialized_end=144
  _globals['_NOBLOCKRESPONSE']._serialized_start=146
  _globals['_NOBLOCKRESPONSE']._serialized_end=187
  _globals['_BLOCKRESPONSE']._serialized_start=189
  _globals['_BLOCKRESPONSE']._serialized_end=257
  _globals['_STATUSREQUEST']._serialized_start=259
  _globals['_STATUSREQUEST']._serialized_end=274
  _globals['_STATUSRESPONSE']._serialized_start=276
  _globals['_STATUSRESPONSE']._serialized_end=336
  _globals['_MESSAGE']._serialized_start=339
  _globals['_MESSAGE']._serialized_end=782
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/trace_config.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.injective.evm.v1 import chain_config_pb2 as injective_dot_evm_dot_v1_dot_chain__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/evm/v1/trace_config.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\x1a#injective/evm/v1/chain_config.proto\"\x9a\x05\n\x0bTraceConfig\x12\x16\n\x06tracer\x18\x01 \x01(\tR\x06tracer\x12\x18\n\x07timeout\x18\x02 \x01(\tR\x07timeout\x12\x16\n\x06reexec\x18\x03 \x01(\x04R\x06reexec\x12\x35\n\rdisable_stack\x18\x05 \x01(\x08\x42\x10\xea\xde\x1f\x0c\x64isableStackR\x0c\x64isableStack\x12;\n\x0f\x64isable_storage\x18\x06 \x01(\x08\x42\x12\xea\xde\x1f\x0e\x64isableStorageR\x0e\x64isableStorage\x12\x14\n\x05\x64\x65\x62ug\x18\x08 \x01(\x08R\x05\x64\x65\x62ug\x12\x14\n\x05limit\x18\t \x01(\x05R\x05limit\x12;\n\toverrides\x18\n \x01(\x0b\x32\x1d.injective.evm.v1.ChainConfigR\toverrides\x12\x35\n\renable_memory\x18\x0b \x01(\x08\x42\x10\xea\xde\x1f\x0c\x65nableMemoryR\x0c\x65nableMemory\x12\x42\n\x12\x65nable_return_data\x18\x0c \x01(\x08\x42\x14\xea\xde\x1f\x10\x65nableReturnDataR\x10\x65nableReturnData\x12>\n\x12tracer_json_config\x18\r \x01(\tB\x10\xea\xde\x1f\x0ctracerConfigR\x10tracerJsonConfig\x12;\n\x0fstate_overrides\x18\x0e \x01(\x0c\x42\x12\xea\xde\x1f\x0estateOverridesR\x0estateOverrides\x12;\n\x0f\x62lock_overrides\x18\x0f \x01(\x0c\x42\x12\xea\xde\x1f\x0e\x62lockOverridesR\x0e\x62lockOverridesJ\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08R\x0e\x64isable_memoryR\x13\x64isable_return_dataB\xd5\x01\n\x14\x63om.injective.evm.v1B\x10TraceConfigProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.trace_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\020TraceConfigProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_TRACECONFIG'].fields_by_name['disable_stack']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['disable_stack']._serialized_options = b'\352\336\037\014disableStack'
  _globals['_TRACECONFIG'].fields_by_name['disable_storage']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['disable_storage']._serialized_options = b'\352\336\037\016disableStorage'
  _globals['_TRACECONFIG'].fields_by_name['enable_memory']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['enable_memory']._serialized_options = b'\352\336\037\014enableMemory'
  _globals['_TRACECONFIG'].fields_by_name['enable_return_data']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['enable_return_data']._serialized_options = b'\352\336\037\020enableReturnData'
  _globals['_TRACECONFIG'].fields_by_name['tracer_json_config']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['tracer_json_config']._serialized_options = b'\352\336\037\014tracerConfig'
  _globals['_TRACECONFIG'].fields_by_name['state_overrides']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['state_overrides']._serialized_options = b'\352\336\037\016stateOverrides'
  _globals['_TRACECONFIG'].fields_by_name['block_overrides']._loaded_options = None
  _globals['_TRACECONFIG'].fields_by_name['block_overrides']._serialized_options = b'\352\336\037\016blockOverrides'
  _globals['_TRACECONFIG']._serialized_start=117
  _globals['_TRACECONFIG']._serialized_end=783
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\"x\n\x16QueryValidatorsRequest\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xb0\x01\n\x17QueryValidatorsResponse\x12L\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\nvalidators\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"a\n\x15QueryValidatorRequest\x12H\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr\"d\n\x16QueryValidatorResponse\x12J\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tvalidator\"\xb4\x01\n QueryValidatorDelegationsRequest\x12H\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xed\x01\n!QueryValidatorDelegationsResponse\x12\x7f\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB \xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\xa8\xe7\xb0*\x01R\x13\x64\x65legationResponses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xbd\x01\n)QueryValidatorUnbondingDelegationsRequest\x12H\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xde\x01\n*QueryValidatorUnbondingDelegationsResponse\x12g\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x12unbondingResponses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xad\x01\n\x16QueryDelegationRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12H\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"v\n\x17QueryDelegationResponse\x12[\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseR\x12\x64\x65legationResponse\"\xb6\x01\n\x1fQueryUnbondingDelegationRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12H\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"r\n QueryUnbondingDelegationResponse\x12N\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06unbond\"\xb5\x01\n QueryDelegatorDelegationsRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd6\x01\n!QueryDelegatorDelegationsResponse\x12h\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x13\x64\x65legationResponses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xbe\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xde\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12g\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x12unbondingResponses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xd0\x02\n\x19QueryRedelegationsRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12O\n\x12src_validator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10srcValidatorAddr\x12O\n\x12\x64st_validator_addr\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10\x64stValidatorAddr\x12\x46\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xd5\x01\n\x1aQueryRedelegationsResponse\x12n\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x15redelegationResponses\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xb4\x01\n\x1fQueryDelegatorValidatorsRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb9\x01\n QueryDelegatorValidatorsResponse\x12L\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\nvalidators\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\xb5\x01\n\x1eQueryDelegatorValidatorRequest\x12?\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\rdelegatorAddr\x12H\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\rvalidatorAddr:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"m\n\x1fQueryDelegatorValidatorResponse\x12J\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\tvalidator\"0\n.QueryAllowedDelegationTransferReceiversRequest\"i\n/QueryAllowedDelegationTransferReceiversResponse\x12\x36\n\taddresses\x18\x01 \x03(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\taddresses\"4\n\x1aQueryHistoricalInfoRequest\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\"Y\n\x1bQueryHistoricalInfoResponse\x12:\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfoR\x04hist\"\x12\n\x10QueryPoolRequest\"P\n\x11QueryPoolResponse\x12;\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x04pool\"\x14\n\x12QueryParamsRequest\"X\n\x13QueryParamsResponse\x12\x41\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params2\xb4\x18\n\x05Query\x12\x9e\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"/\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xac\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\"@\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd9\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"L\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xfe\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xcc\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"]\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xfc\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"r\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xce\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"A\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xfe\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc6\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"N\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd5\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"K\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xe3\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"\\\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\x81\x02\n\"AllowedDelegationTransferReceivers\x12\x46.cosmos.staking.v1beta1.QueryAllowedDelegationTransferReceiversRequest\x1aG.cosmos.staking.v1beta1.QueryAllowedDelegationTransferReceiversResponse\"J\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02?\x12=/cosmos/staking/v1beta1/allowed_delegation_transfer_receivers\x12\xb8\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"=\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x86\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\")\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x8e\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"+\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB\xd0\x01\n\x1a\x63om.cosmos.staking.v1beta1B\nQueryProtoP\x01Z,github.com/cosmos/cosmos-sdk/x/staking/types\xa2\x02\x03\x43SX\xaa\x02\x16\x43osmos.Staking.V1beta1\xca\x02\x16\x43osmos\\Staking\\V1beta1\xe2\x02\"Cosmos\\Staking\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Staking::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.staking.v1beta1B\nQueryProtoP\001Z,github.com/cosmos/cosmos-sdk/x/staking/types\242\002\003CSX\252\002\026Cosmos.Staking.V1beta1\312\002\026Cosmos\\Staking\\V1beta1\342\002\"Cosmos\\Staking\\V1beta1\\GPBMetadata\352\002\030Cosmos::Staking::V1beta1'
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYVALIDATORREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\252\337\037\023DelegationResponses\250\347\260*\001'
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['src_validator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['src_validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['dst_validator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['dst_validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYREDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._loaded_options = None
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSRESPONSE'].fields_by_name['addresses']._loaded_options = None
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSRESPONSE'].fields_by_name['addresses']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._loaded_options = None
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Validators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators'
  _globals['_QUERY'].methods_by_name['Validator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validator']._serialized_options = b'\210\347\260*\001\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Delegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Delegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Redelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Redelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._serialized_options = b'\210\347\260*\001\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['AllowedDelegationTransferReceivers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllowedDelegationTransferReceivers']._serialized_options = b'\210\347\260*\001\202\323\344\223\002?\022=/cosmos/staking/v1beta1/allowed_delegation_transfer_receivers'
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._serialized_options = b'\210\347\260*\001\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}'
  _globals['_QUERY'].methods_by_name['Pool']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Pool']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params'
  _globals['_QUERYVALIDATORSREQUEST']._serialized_start=271
  _globals['_QUERYVALIDATORSREQUEST']._serialized_end=391
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_start=394
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_end=570
  _globals['_QUERYVALIDATORREQUEST']._serialized_start=572
  _globals['_QUERYVALIDATORREQUEST']._serialized_end=669
  _globals['_QUERYVALIDATORRESPONSE']._serialized_start=671
  _globals['_QUERYVALIDATORRESPONSE']._serialized_end=771
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_start=774
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_end=954
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_start=957
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_end=1194
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=1197
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=1386
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=1389
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=1611
  _globals['_QUERYDELEGATIONREQUEST']._serialized_start=1614
  _globals['_QUERYDELEGATIONREQUEST']._serialized_end=1787
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_start=1789
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_end=1907
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_start=1910
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_end=2092
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_start=2094
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_end=2208
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_start=2211
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_end=2392
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_start=2395
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_end=2609
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=2612
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=2802
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=2805
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=3027
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_start=3030
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_end=3366
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_start=3369
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_end=3582
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_start=3585
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_end=3765
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_start=3768
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_end=3953
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_start=3956
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_end=4137
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_start=4139
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_end=4248
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSREQUEST']._serialized_start=4250
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSREQUEST']._serialized_end=4298
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSRESPONSE']._serialized_start=4300
  _globals['_QUERYALLOWEDDELEGATIONTRANSFERRECEIVERSRESPONSE']._serialized_end=4405
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_start=4407
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_end=4459
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_start=4461
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_end=4550
  _globals['_QUERYPOOLREQUEST']._serialized_start=4552
  _globals['_QUERYPOOLREQUEST']._serialized_end=4570
  _globals['_QUERYPOOLRESPONSE']._serialized_start=4572
  _globals['_QUERYPOOLRESPONSE']._serialized_end=4652
  _globals['_QUERYPARAMSREQUEST']._serialized_start=4654
  _globals['_QUERYPARAMSREQUEST']._serialized_end=4674
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=4676
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=4764
  _globals['_QUERY']._serialized_start=4767
  _globals['_QUERY']._serialized_end=7891
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/postal_address.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n google/type/postal_address.proto\x12\x0bgoogle.type\"\x8d\x03\n\rPostalAddress\x12\x1a\n\x08revision\x18\x01 \x01(\x05R\x08revision\x12\x1f\n\x0bregion_code\x18\x02 \x01(\tR\nregionCode\x12#\n\rlanguage_code\x18\x03 \x01(\tR\x0clanguageCode\x12\x1f\n\x0bpostal_code\x18\x04 \x01(\tR\npostalCode\x12!\n\x0csorting_code\x18\x05 \x01(\tR\x0bsortingCode\x12/\n\x13\x61\x64ministrative_area\x18\x06 \x01(\tR\x12\x61\x64ministrativeArea\x12\x1a\n\x08locality\x18\x07 \x01(\tR\x08locality\x12 \n\x0bsublocality\x18\x08 \x01(\tR\x0bsublocality\x12#\n\raddress_lines\x18\t \x03(\tR\x0c\x61\x64\x64ressLines\x12\x1e\n\nrecipients\x18\n \x03(\tR\nrecipients\x12\"\n\x0corganization\x18\x0b \x01(\tR\x0corganizationB\xbd\x01\n\x0f\x63om.google.typeB\x12PostalAddressProtoP\x01ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\xf8\x01\x01\xa2\x02\x03GTX\xaa\x02\x0bGoogle.Type\xca\x02\x0bGoogle\\Type\xe2\x02\x17Google\\Type\\GPBMetadata\xea\x02\x0cGoogle::Typeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.postal_address_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\022PostalAddressProtoP\001ZFgoogle.golang.org/genproto/googleapis/type/postaladdress;postaladdress\370\001\001\242\002\003GTX\252\002\013Google.Type\312\002\013Google\\Type\342\002\027Google\\Type\\GPBMetadata\352\002\014Google::Type'
  _globals['_POSTALADDRESS']._serialized_start=50
  _globals['_POSTALADDRESS']._serialized_end=447
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/txfees/v1beta1/txfees.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/txfees/v1beta1/txfees.proto\x12\x18injective.txfees.v1beta1\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\"\x99\x0c\n\x06Params\x12R\n\x15max_gas_wanted_per_tx\x18\x01 \x01(\x04\x42 \xf2\xde\x1f\x1cyaml:\"max_gas_wanted_per_tx\"R\x11maxGasWantedPerTx\x12S\n\x15high_gas_tx_threshold\x18\x02 \x01(\x04\x42 \xf2\xde\x1f\x1cyaml:\"high_gas_tx_threshold\"R\x12highGasTxThreshold\x12\x8b\x01\n\x1dmin_gas_price_for_high_gas_tx\x18\x03 \x01(\tBK\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f$yaml:\"min_gas_price_for_high_gas_tx\"R\x17minGasPriceForHighGasTx\x12O\n\x13mempool1559_enabled\x18\x04 \x01(\x08\x42\x1e\xf2\xde\x1f\x1ayaml:\"mempool1559_enabled\"R\x12mempool1559Enabled\x12_\n\rmin_gas_price\x18\x05 \x01(\tB;\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x14yaml:\"min_gas_price\"R\x0bminGasPrice\x12\x88\x01\n\x1b\x64\x65\x66\x61ult_base_fee_multiplier\x18\x06 \x01(\tBI\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\"yaml:\"default_base_fee_multiplier\"R\x18\x64\x65\x66\x61ultBaseFeeMultiplier\x12|\n\x17max_base_fee_multiplier\x18\x07 \x01(\tBE\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1eyaml:\"max_base_fee_multiplier\"R\x14maxBaseFeeMultiplier\x12@\n\x0ereset_interval\x18\x08 \x01(\x03\x42\x19\xf2\xde\x1f\x15yaml:\"reset_interval\"R\rresetInterval\x12v\n\x15max_block_change_rate\x18\t \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1cyaml:\"max_block_change_rate\"R\x12maxBlockChangeRate\x12\x93\x01\n\x1ftarget_block_space_percent_rate\x18\n \x01(\tBM\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f&yaml:\"target_block_space_percent_rate\"R\x1btargetBlockSpacePercentRate\x12~\n\x18recheck_fee_low_base_fee\x18\x0b \x01(\tBF\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x1fyaml:\"recheck_fee_low_base_fee\"R\x14recheckFeeLowBaseFee\x12\x81\x01\n\x19recheck_fee_high_base_fee\x18\x0c \x01(\tBG\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f yaml:\"recheck_fee_high_base_fee\"R\x15recheckFeeHighBaseFee\x12\xb0\x01\n)recheck_fee_base_fee_threshold_multiplier\x18\r \x01(\tBW\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xf2\xde\x1f\x30yaml:\"recheck_fee_base_fee_threshold_multiplier\"R$recheckFeeBaseFeeThresholdMultiplier:\x16\xe8\xa0\x1f\x01\x8a\xe7\xb0*\rtxfees/ParamsB\xff\x01\n\x1c\x63om.injective.txfees.v1beta1B\x0bTxfeesProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\xa2\x02\x03ITX\xaa\x02\x18Injective.Txfees.V1beta1\xca\x02\x18Injective\\Txfees\\V1beta1\xe2\x02$Injective\\Txfees\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Txfees::V1beta1\xc0\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.txfees.v1beta1.txfees_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.txfees.v1beta1B\013TxfeesProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/txfees/types\242\002\003ITX\252\002\030Injective.Txfees.V1beta1\312\002\030Injective\\Txfees\\V1beta1\342\002$Injective\\Txfees\\V1beta1\\GPBMetadata\352\002\032Injective::Txfees::V1beta1\300\343\036\001'
  _globals['_PARAMS'].fields_by_name['max_gas_wanted_per_tx']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_gas_wanted_per_tx']._serialized_options = b'\362\336\037\034yaml:\"max_gas_wanted_per_tx\"'
  _globals['_PARAMS'].fields_by_name['high_gas_tx_threshold']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['high_gas_tx_threshold']._serialized_options = b'\362\336\037\034yaml:\"high_gas_tx_threshold\"'
  _globals['_PARAMS'].fields_by_name['min_gas_price_for_high_gas_tx']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_gas_price_for_high_gas_tx']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037$yaml:\"min_gas_price_for_high_gas_tx\"'
  _globals['_PARAMS'].fields_by_name['mempool1559_enabled']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['mempool1559_enabled']._serialized_options = b'\362\336\037\032yaml:\"mempool1559_enabled\"'
  _globals['_PARAMS'].fields_by_name['min_gas_price']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['min_gas_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\024yaml:\"min_gas_price\"'
  _globals['_PARAMS'].fields_by_name['default_base_fee_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['default_base_fee_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\"yaml:\"default_base_fee_multiplier\"'
  _globals['_PARAMS'].fields_by_name['max_base_fee_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_base_fee_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\036yaml:\"max_base_fee_multiplier\"'
  _globals['_PARAMS'].fields_by_name['reset_interval']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['reset_interval']._serialized_options = b'\362\336\037\025yaml:\"reset_interval\"'
  _globals['_PARAMS'].fields_by_name['max_block_change_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['max_block_change_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\034yaml:\"max_block_change_rate\"'
  _globals['_PARAMS'].fields_by_name['target_block_space_percent_rate']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['target_block_space_percent_rate']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037&yaml:\"target_block_space_percent_rate\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_low_base_fee']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_low_base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037\037yaml:\"recheck_fee_low_base_fee\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_high_base_fee']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_high_base_fee']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\037 yaml:\"recheck_fee_high_base_fee\"'
  _globals['_PARAMS'].fields_by_name['recheck_fee_base_fee_threshold_multiplier']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['recheck_fee_base_fee_threshold_multiplier']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\362\336\0370yaml:\"recheck_fee_base_fee_threshold_multiplier\"'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\rtxfees/Params'
  _globals['_PARAMS']._serialized_start=139
  _globals['_PARAMS']._serialized_end=1700
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ibc/applications/fee/v1/genesis.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a!ibc/core/channel/v1/channel.proto\"\x91\x04\n\x0cGenesisState\x12\\\n\x0fidentified_fees\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00R\x0eidentifiedFees\x12\x62\n\x14\x66\x65\x65_enabled_channels\x18\x02 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB\x04\xc8\xde\x1f\x00R\x12\x66\x65\x65\x45nabledChannels\x12[\n\x11registered_payees\x18\x03 \x03(\x0b\x32(.ibc.applications.fee.v1.RegisteredPayeeB\x04\xc8\xde\x1f\x00R\x10registeredPayees\x12\x80\x01\n\x1eregistered_counterparty_payees\x18\x04 \x03(\x0b\x32\x34.ibc.applications.fee.v1.RegisteredCounterpartyPayeeB\x04\xc8\xde\x1f\x00R\x1cregisteredCounterpartyPayees\x12_\n\x10\x66orward_relayers\x18\x05 \x03(\x0b\x32..ibc.applications.fee.v1.ForwardRelayerAddressB\x04\xc8\xde\x1f\x00R\x0f\x66orwardRelayers\"K\n\x11\x46\x65\x65\x45nabledChannel\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\"`\n\x0fRegisteredPayee\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\x12\x14\n\x05payee\x18\x03 \x01(\tR\x05payee\"\x85\x01\n\x1bRegisteredCounterpartyPayee\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12\x18\n\x07relayer\x18\x02 \x01(\tR\x07relayer\x12-\n\x12\x63ounterparty_payee\x18\x03 \x01(\tR\x11\x63ounterpartyPayee\"s\n\x15\x46orwardRelayerAddress\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12@\n\tpacket_id\x18\x02 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00R\x08packetIdB\xe1\x01\n\x1b\x63om.ibc.applications.fee.v1B\x0cGenesisProtoP\x01Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\xa2\x02\x03IAF\xaa\x02\x17Ibc.Applications.Fee.V1\xca\x02\x17Ibc\\Applications\\Fee\\V1\xe2\x02#Ibc\\Applications\\Fee\\V1\\GPBMetadata\xea\x02\x1aIbc::Applications::Fee::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.ibc.applications.fee.v1B\014GenesisProtoP\001Z5github.com/cosmos/ibc-go/v8/modules/apps/29-fee/types\242\002\003IAF\252\002\027Ibc.Applications.Fee.V1\312\002\027Ibc\\Applications\\Fee\\V1\342\002#Ibc\\Applications\\Fee\\V1\\GPBMetadata\352\002\032Ibc::Applications::Fee::V1'
  _globals['_GENESISSTATE'].fields_by_name['identified_fees']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['identified_fees']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['fee_enabled_channels']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['registered_payees']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['registered_payees']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['registered_counterparty_payees']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['registered_counterparty_payees']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['forward_relayers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['forward_relayers']._serialized_options = b'\310\336\037\000'
  _globals['_FORWARDRELAYERADDRESS'].fields_by_name['packet_id']._loaded_options = None
  _globals['_FORWARDRELAYERADDRESS'].fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=159
  _globals['_GENESISSTATE']._serialized_end=688
  _globals['_FEEENABLEDCHANNEL']._serialized_start=690
  _globals['_FEEENABLEDCHANNEL']._serialized_end=765
  _globals['_REGISTEREDPAYEE']._serialized_start=767
  _globals['_REGISTEREDPAYEE']._serialized_end=863
  _globals['_REGISTEREDCOUNTERPARTYPAYEE']._serialized_start=866
  _globals['_REGISTEREDCOUNTERPARTYPAYEE']._serialized_end=999
  _globals['_FORWARDRELAYERADDRESS']._serialized_start=1001
  _globals['_FORWARDRELAYERADDRESS']._serialized_end=1116
# @@protoc_insertion_point(module_scope)
